import { Grant, IGrantable } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { IStringParameter, StringParameterProps } from 'aws-cdk-lib/aws-ssm';
import { RemovalPolicy, ResourceEnvironment, Stack } from 'aws-cdk-lib/core';
import { Construct } from 'constructs';
import { SopsSync, SopsSyncOptions } from './SopsSync';
/**
 * The configuration options of the StringParameter
 */
export interface SopsStringParameterProps extends SopsSyncOptions, StringParameterProps {
    readonly encryptionKey: IKey;
}
/**
 * A drop in replacement for the normal String Parameter, that is populated with the encrypted
 * content of the given sops file.
 */
export declare class SopsStringParameter extends Construct implements IStringParameter {
    private readonly parameter;
    readonly sync: SopsSync;
    readonly encryptionKey: IKey;
    readonly stack: Stack;
    readonly env: ResourceEnvironment;
    readonly parameterArn: string;
    readonly parameterName: string;
    readonly parameterType: string;
    readonly stringValue: string;
    constructor(scope: Construct, id: string, props: SopsStringParameterProps);
    grantRead(grantee: IGrantable): Grant;
    grantWrite(grantee: IGrantable): Grant;
    applyRemovalPolicy(policy: RemovalPolicy): void;
}
